pub struct AppContext { /* private fields */ }Expand description
The application context for managing the application lifecycle.
Implementations
Sourceimpl AppContext
impl AppContext
Sourcepub fn new(update: UpdateManager, diagnostics: Diagnostics) -> Self
pub fn new(update: UpdateManager, diagnostics: Diagnostics) -> Self
Create a new application context using the given UpdateManager.
Sourcepub fn diagnostics(&self) -> Diagnostics
pub fn diagnostics(&self) -> Diagnostics
Get the Diagnostics of the application.
Sourcepub fn update(&self) -> UpdateManager
pub fn update(&self) -> UpdateManager
Get the UpdateManager of the application.
Sourcepub fn exit(&self)
pub fn exit(&self)
Make the application exit by setting Update::EXIT.
Sourcepub fn hook_signal<T: 'static, S: Signal<T>>(&self, signal: &mut S)
pub fn hook_signal<T: 'static, S: Signal<T>>(&self, signal: &mut S)
Hook the given Signal to the UpdateManager of this application.
This makes the signal reactive, so it will notify the renderer when the inner value changes.
Sourcepub fn use_signal<T: 'static, S: Signal<T>>(&self, signal: S) -> S
pub fn use_signal<T: 'static, S: Signal<T>>(&self, signal: S) -> S
Hook the given Signal to the UpdateManager of this application and return it.
See AppContext::hook_signal for more.
Sourcepub fn use_state<T: 'static>(&self, value: T) -> StateSignal<T>
pub fn use_state<T: 'static>(&self, value: T) -> StateSignal<T>
Shortcut for creating and hooking a StateSignal into the application lifecycle.
Sourcepub fn use_memoized<T: 'static>(
&self,
value: impl Fn() -> T + 'static,
) -> MemoizedSignal<T>
pub fn use_memoized<T: 'static>( &self, value: impl Fn() -> T + 'static, ) -> MemoizedSignal<T>
Shortcut for creating and hooking a MemoizedSignal into the application lifecycle.
Sourcepub fn use_fixed<T: 'static>(&self, value: T) -> FixedSignal<T>
pub fn use_fixed<T: 'static>(&self, value: T) -> FixedSignal<T>
Shortcut for creating and hooking a FixedSignal into the application lifecycle.
Sourcepub fn use_eval<T: 'static>(
&self,
eval: impl Fn() -> T + 'static,
) -> EvalSignal<T>
pub fn use_eval<T: 'static>( &self, eval: impl Fn() -> T + 'static, ) -> EvalSignal<T>
Shortcut for creating and hooking an EvalSignal into the application lifecycle.