Struct ComponentAdapter

pub struct ComponentAdapter<S: State, C: Component<S>> { /* private fields */ }
An adapter around a Component to make it usable as a Widget.

You can still call methods of the inner Component, due to Deref coercion

Implementations

Source

impl<S: State, C: Component<S>> ComponentAdapter<S, C>

pub fn new(inner: C) -> Self

Creates a new ComponentAdapter by using the given Component.