pub enum AaConfig {
Area,
Msaa8,
Msaa16,
}Expand description
Represents the anti-aliasing method to use during a render pass.
Can be configured for a render operation by setting RenderParams::antialiasing_method.
Each value of this can only be used if the corresponding field on AaSupport was used.
This can be converted into an AaSupport using Iterator::collect,
as AaSupport implements FromIterator.
Variants
Area
Area anti-aliasing, where the alpha value for a pixel is computed from integrating the winding number over its square area.
This technique produces very accurate values when the shape has winding number of 0 or 1 everywhere, but can result in conflation artifacts otherwise. It generally has better performance than the multi-sampling methods.
Can only be used if enabled for the Renderer.
Msaa8
8x Multisampling
Can only be used if enabled for the Renderer.
Msaa16
16x Multisampling
Can only be used if enabled for the Renderer.