Enum PresentMode

#[repr(C)]
pub enum PresentMode { AutoVsync = 0, AutoNoVsync = 1, Fifo = 2, FifoRelaxed = 3, Immediate = 4, Mailbox = 5, }
Behavior of the presentation engine based on frame rate.

Variants



AutoVsync = 0

Chooses FifoRelaxed -> Fifo based on availability.

Because of the fallback behavior, it is supported everywhere.



AutoNoVsync = 1

Chooses Immediate -> Mailbox -> Fifo (on web) based on availability.

Because of the fallback behavior, it is supported everywhere.



Fifo = 2

Presentation frames are kept in a First-In-First-Out queue approximately 3 frames long. Every vertical blanking period, the presentation engine will pop a frame off the queue to display. If there is no frame to display, it will present the same frame again until the next vblank.

When a present command is executed on the gpu, the presented image is added on the queue.

No tearing will be observed.

Calls to get_current_texture will block until there is a spot in the queue.

Supported on all platforms.

If you don’t know what mode to choose, choose this mode. This is traditionally called “Vsync On”.



FifoRelaxed = 3

Presentation frames are kept in a First-In-First-Out queue approximately 3 frames long. Every vertical blanking period, the presentation engine will pop a frame off the queue to display. If there is no frame to display, it will present the same frame until there is a frame in the queue. The moment there is a frame in the queue, it will immediately pop the frame off the queue.

When a present command is executed on the gpu, the presented image is added on the queue.

Tearing will be observed if frames last more than one vblank as the front buffer.

Calls to get_current_texture will block until there is a spot in the queue.

Supported on AMD on Vulkan.

This is traditionally called “Adaptive Vsync”



Immediate = 4

Presentation frames are not queued at all. The moment a present command is executed on the GPU, the presented image is swapped onto the front buffer immediately.

Tearing can be observed.

Supported on most platforms except older DX12 and Wayland.

This is traditionally called “Vsync Off”.



Mailbox = 5

Presentation frames are kept in a single-frame queue. Every vertical blanking period, the presentation engine will pop a frame from the queue. If there is no frame to display, it will present the same frame again until the next vblank.

When a present command is executed on the gpu, the frame will be put into the queue. If there was already a frame in the queue, the new frame will replace the old frame on the queue.

No tearing will be observed.

Supported on DX12 on Windows 10, NVidia on Vulkan and Wayland on Vulkan.

This is traditionally called “Fast Vsync”