Enum Dimension

pub enum Dimension {
    Length(f32),
    Percent(f32),
    Auto,
}
A unit of linear measurement

This is commonly combined with Rect, Point and Size<T>.

Variants



Length(f32)

An absolute length in some abstract units. Users of Taffy may define what they correspond to in their application (pixels, logical pixels, mm, etc) as they see fit.



Percent(f32)

A percentage length relative to the size of the containing block.

NOTE: percentages are represented as a f32 value in the range [0.0, 1.0] NOT the range [0.0, 100.0]



Auto

The dimension should be automatically computed

Implementations

Source

impl Dimension

pub fn into_option(self) -> Option<f32>

Get Length value if value is Length variant