Enum Ref

pub enum Ref<'a, T> {
    Owned(T),
    Borrow(&'a T),
    Arc(Arc<T>),
}
Represents a reference to a value of type T.

Due to Rust’s temporal borrowing rules, returning a reference to a value may not be always possible, so this enum is used to represent one by having multiple variants for multiple types of references.

Variants



Owned(T)

An owned value. Useful for Copy types.



Borrow(&'a T)

A borrowed reference.



Arc(Arc<T>)

An Arc reference.