pub enum MaybeSignal<T> {
Signal(ArcSignal<T>),
Value(Arc<T>),
}Expand description
A value which may be a signal or a fixed value.
Variants
Implementations
Sourceimpl<T: 'static> MaybeSignal<T>
impl<T: 'static> MaybeSignal<T>
Sourcepub fn signal(signal: ArcSignal<T>) -> Self
pub fn signal(signal: ArcSignal<T>) -> Self
Wrap a Signal inside a MaybeSignal.
Sourcepub fn value(value: T) -> Self
pub fn value(value: T) -> Self
Wrap a value inside a MaybeSignal.
Sourcepub fn get(&self) -> Ref<'_, T>
pub fn get(&self) -> Ref<'_, T>
Get a reference to the current value.
If the value is a signal, the signal’s current value is returned, otherwise a Ref::Arc of the value is returned.
Sourcepub fn into_signal(self) -> ArcSignal<T>
pub fn into_signal(self) -> ArcSignal<T>
Converts the MaybeSignal into a ArcSignal.
If the value is a MaybeSignal::Value, a FixedSignal is created.
Sourcepub fn as_signal(&self) -> Option<ArcSignal<T>>
pub fn as_signal(&self) -> Option<ArcSignal<T>>
Converts the MaybeSignal into an ArcSignal if it is a MaybeSignal::Signal.
Sourcepub fn map<U: 'static>(
self,
map: impl Fn(Ref<'_, T>) -> Ref<'_, U> + 'static,
) -> MaybeSignal<U>
pub fn map<U: 'static>( self, map: impl Fn(Ref<'_, T>) -> Ref<'_, U> + 'static, ) -> MaybeSignal<U>
Applies the given mapping function to the signal.
Returns a MaybeSignal containing a MapSignal which maps the inner value of the signal.