pub struct TaskRunner { /* private fields */ }Expand description
The Maycoon Task Runner for running asynchronous tasks using a thread pool from the futures crate.
Initialize it using the TaskConfig inside the MayConfig.
Implementations
Sourceimpl TaskRunner
impl TaskRunner
Sourcepub fn new(stack_size: usize, workers: NonZeroUsize) -> Result<Self, Error>
pub fn new(stack_size: usize, workers: NonZeroUsize) -> Result<Self, Error>
Creates a new TaskRunner with the given thread stack size and worker/thread count.
Sourcepub fn run<Fut>(&self, fut: Fut) -> TaskHandle<Fut::Output>
pub fn run<Fut>(&self, fut: Fut) -> TaskHandle<Fut::Output>
Runs the given Future on the task runner thread pool and returns the output.