Module widget

Contains the core widget functionalities

Traits

Widget
The base trait for all widgets.
WidgetChildExt
An extension trait for widgets with a single child widget.
WidgetChildrenExt
An extension trait for widgets with multiple child widgets.
WidgetLayoutExt
An extension trait for widgets with a layout style.

Type Aliases

BoxedWidget
A boxed widget.