Contains the core widget functionalities
Traits
- Widget
- The base trait for all widgets.
- Widget
Child Ext - An extension trait for widgets with a single child widget.
- Widget
Children Ext - An extension trait for widgets with multiple child widgets.
- Widget
Layout Ext - An extension trait for widgets with a layout style.
Type Aliases
- Boxed
Widget - A boxed widget.