Contains useful types for interacting with winit.
Structs
- Activation
Token - An opaque token used to activate the
Window. - Active
Event Loop - Target that associates windows with an
EventLoop. - Async
Request Serial - A unique identifier of the winit’s async request.
- Cursor
Icon Parse Error - An error which could be returned when parsing
CursorIcon. - Custom
Cursor - Use a custom image as a cursor (mouse pointer).
- Custom
Cursor Source - Source for
CustomCursor. - Device
Id - Identifier of an input device.
- Event
Loop - Provides a way to retrieve events from the system and from the windows that were registered to the events loop.
- Event
Loop Builder - Object that allows building the event loop.
- Event
Loop Closed - The error that is returned when an
EventLoopProxyattempts to wake up anEventLoopthat no longer exists. - Event
Loop Proxy - Used to send custom events to
EventLoop. - Icon
- An icon used for the window titlebar, taskbar, etc.
- Inner
Size Writer - Handle to synchronously change the size of the window from the
WindowEvent. - KeyEvent
- Describes a keyboard input targeting a window.
- Modifiers
- Describes keyboard modifiers event.
- Modifiers
State - Represents the current state of the keyboard modifiers
- Owned
Display Handle - A proxy for the underlying display handle.
- RawKey
Event - Describes a keyboard input as a raw device event.
- SmolStr
- A
SmolStris a string type that has the following properties: - Touch
- Represents a touch event
- Window
- Represents a window.
- Window
Attributes - Attributes used when creating a window.
- Window
Buttons - Window
Id - Identifier of a window. Unique for each window.
Enums
- BadIcon
- An error produced when using
Icon::from_rgbawith invalid arguments. - BadImage
- An error produced when using
CustomCursor::from_rgbawith invalid arguments. - Control
Flow - Set through
ActiveEventLoop::set_control_flow(). - Cursor
- See
Window::set_cursor()for more details. - Cursor
Grab Mode - The behavior of cursor grabbing.
- Cursor
Icon - Describes the appearance of the (usually mouse) cursor icon.
- Device
Event - Represents raw hardware events that are not associated with any particular window.
- Device
Events - Control when device events are captured.
- Element
State - Describes the input state of a key.
- Event
- Describes a generic event.
- Force
- Describes the force of a touch event
- Fullscreen
- Fullscreen modes.
- Ime
- Describes input method events.
- ImePurpose
- Generic IME purposes for use in
Window::set_ime_purpose. - Key
- Key represents the meaning of a keypress.
- KeyCode
- Code representing the location of a physical key
- KeyLocation
- The location of the key on the keyboard.
- Modifiers
KeyState - The state of the particular modifiers key.
- Mouse
Button - Describes a button of a mouse controller.
- Mouse
Scroll Delta - Describes a difference in the mouse scroll wheel state.
- Named
Key - A
Key::Namedvalue - Native
Key - Contains the platform-native logical key identifier
- Native
KeyCode - Contains the platform-native physical key identifier
- Physical
Key - Represents the location of a physical key.
- Resize
Direction - Defines the orientation that a window resize will be performed.
- Start
Cause - Describes the reason the event loop is resuming.
- Theme
- The theme variant to use.
- Touch
Phase - Describes touch-screen input state.
- User
Attention Type - Platform-specific
- Window
Event - Describes an event from a [
Window]. - Window
Level - A window level groups windows with respect to their z-position.
Constants
- MAX_
CURSOR_ SIZE - The maximum width and height for a cursor when using
CustomCursor::from_rgba.