Module window

Contains useful types for interacting with winit.

Structs

DeviceId
Identifier of an input device.
InnerSizeWriter
Handle to synchronously change the size of the window from the WindowEvent.
KeyEvent
Describes a keyboard input targeting a window.
Modifiers
Describes keyboard modifiers event.
ModifiersState
Represents the current state of the keyboard modifiers
RawKeyEvent
Describes a keyboard input as a raw device event.
SmolStr
A SmolStr is a string type that has the following properties:
Touch
Represents a touch event

Enums

DeviceEvent
Represents raw hardware events that are not associated with any particular window.
ElementState
Describes the input state of a key.
Event
Describes a generic event.
Force
Describes the force of a touch event
Ime
Describes input method events.
Key
Key represents the meaning of a keypress.
KeyCode
Code representing the location of a physical key
KeyLocation
The location of the key on the keyboard.
ModifiersKeyState
The state of the particular modifiers key.
MouseButton
Describes a button of a mouse controller.
MouseScrollDelta
Describes a difference in the mouse scroll wheel state.
NamedKey
A Key::Named value
NativeKey
Contains the platform-native logical key identifier
NativeKeyCode
Contains the platform-native physical key identifier
PhysicalKey
Represents the location of a physical key.
StartCause
Describes the reason the event loop is resuming.
TouchPhase
Describes touch-screen input state.
WindowEvent
Describes an event from a [Window].

Type Aliases

AxisId
Identifier for a specific analog axis on some device.
ButtonId
Identifier for a specific button on some device.