Contains useful types for interacting with winit.
Structs
- Device
Id - Identifier of an input device.
- Inner
Size Writer - Handle to synchronously change the size of the window from the
WindowEvent. - KeyEvent
- Describes a keyboard input targeting a window.
- Modifiers
- Describes keyboard modifiers event.
- Modifiers
State - Represents the current state of the keyboard modifiers
- RawKey
Event - Describes a keyboard input as a raw device event.
- SmolStr
- A
SmolStris a string type that has the following properties: - Touch
- Represents a touch event
Enums
- Device
Event - Represents raw hardware events that are not associated with any particular window.
- Element
State - Describes the input state of a key.
- Event
- Describes a generic event.
- Force
- Describes the force of a touch event
- Ime
- Describes input method events.
- Key
- Key represents the meaning of a keypress.
- KeyCode
- Code representing the location of a physical key
- KeyLocation
- The location of the key on the keyboard.
- Modifiers
KeyState - The state of the particular modifiers key.
- Mouse
Button - Describes a button of a mouse controller.
- Mouse
Scroll Delta - Describes a difference in the mouse scroll wheel state.
- Named
Key - A
Key::Namedvalue - Native
Key - Contains the platform-native logical key identifier
- Native
KeyCode - Contains the platform-native physical key identifier
- Physical
Key - Represents the location of a physical key.
- Start
Cause - Describes the reason the event loop is resuming.
- Touch
Phase - Describes touch-screen input state.
- Window
Event - Describes an event from a [
Window].